@@ -1,11 +1,9 @@
-# Copyright 2021 UW-IT, University of Washington
-# SPDX-License-Identifier: Apache-2.0
-
 import json
 from urllib.parse import quote
 from restclients_core.exceptions import DataFailureException
 from uw_pws import PWS
-from uw_sws.dao import SWS_DAO, SWS_TIMEZONE, sws_now
+from uw_sws.dao import SWS_DAO
+
 
 QUARTER_SEQ = ["winter", "spring", "summer", "autumn"]
 DAO = SWS_DAO()
