@@ -1,15 +1,14 @@
-# Copyright 2021 UW-IT, University of Washington
-# SPDX-License-Identifier: Apache-2.0
-
 import json
+import os
 import re
-from uw_pws.models import Person
-from uw_sws.exceptions import (
-    InvalidCanvasIndependentStudyCourse, InvalidCanvasSection)
-from uw_sws.util import (
-    abbr_week_month_day_str, convert_to_begin_of_day, convert_to_end_of_day,
-    str_to_datetime, str_to_date, date_to_str)
-from uw_sws.dao import sws_now
+from datetime import datetime
+from time import strftime
+from dateutil.parser import parse
+from uw_pws.models import Person, Entity
+from uw_sws.exceptions import (InvalidCanvasIndependentStudyCourse,
+                               InvalidCanvasSection)
+from uw_sws.util import (abbr_week_month_day_str, convert_to_begin_of_day,
+                         convert_to_end_of_day)
 from restclients_core import models
 
 SWS_TERM_LABEL = "{year},{quarter}"
@@ -21,6 +20,19 @@ CANVAS_IND_STUDY_COURSE_ID = (
     "{year}-{quarter}-{curr_abbr}-{course_num}-{section_id}-{inst_regid}")
 
 
+def str_to_datetime(s):
+    return parse(s) if (s is not None and len(s)) else None
+
+
+def str_to_date(s):
+    dt = str_to_datetime(s)
+    return dt.date() if dt is not None else None
+
+
+def date_to_str(dt):
+    return str(dt) if dt is not None else None
+
+
 class LastEnrolled(models.Model):
     href = models.CharField(max_length=200)
     quarter = models.CharField(max_length=16)
@@ -79,7 +91,6 @@ class SwsPerson(models.Model):
     gender = models.CharField(max_length=1, null=True, blank=True)
     first_name = models.CharField(max_length=100)
     last_name = models.CharField(max_length=100)
-    pronouns = models.CharField(max_length=140, null=True, blank=True)
     student_name = models.CharField(max_length=255)
     student_number = models.SlugField(max_length=16, null=True, blank=True)
     student_system_key = models.SlugField(max_length=16, null=True, blank=True)
@@ -100,10 +111,6 @@ class SwsPerson(models.Model):
         related_name='permanent_address')
     permanent_phone = models.CharField(max_length=64, null=True, blank=True)
     visa_type = models.CharField(max_length=2, null=True, blank=True)
-    veteran_code = models.CharField(max_length=2)
-
-    def not_veteran(self):
-        return self.veteran_code == "0"
 
     def is_F1(self):
         return self.visa_type is not None and self.visa_type.lower() == 'f1'
@@ -119,7 +126,6 @@ class SwsPerson(models.Model):
             'email': self.email,
             'first_name': self.first_name,
             'last_name': self.last_name,
-            'pronouns': self.pronouns,
             'student_name': self.student_name,
             'student_number': self.student_number,
             'employee_id': self.employee_id,
@@ -129,69 +135,13 @@ class SwsPerson(models.Model):
             'permanent_address': get_student_address_json(
                 self.permanent_address),
             'permanent_phone': self.permanent_phone,
-            'visa_type': self.visa_type,
-            'veteran_code': self.veteran_code
+            'visa_type': self.visa_type
                 }
 
     def __str__(self):
         return json.dumps(self.json_data())
 
 
-class StudentAdviser(models.Model):
-    is_active = models.BooleanField()
-    is_dept_adviser = models.BooleanField()
-    full_name = models.CharField(max_length=128)
-    pronouns = models.CharField(max_length=140, null=True, blank=True)
-    email_address = models.CharField(max_length=128)
-    phone_number = models.CharField(max_length=32, null=True,
-                                    blank=True, default=None)
-    uwnetid = models.CharField(max_length=32)
-    regid = models.CharField(max_length=32)
-    program = models.CharField(max_length=128, null=True,
-                               blank=True, default=None)
-    booking_url = models.CharField(max_length=128, null=True,
-                                   blank=True, default=None)
-    metadata = models.CharField(max_length=128, null=True, blank=True)
-
-    def __init__(self, *args, **kwargs):
-        data = kwargs.get("data")
-        if data is None:
-            return super(StudentAdviser, self).__init__(*args, **kwargs)
-        self.full_name = data.get("AdvisingFullName")
-        self.email_address = data.get("AdvisingEmailAddress")
-        self.phone_number = data.get("AdvisingPhoneNumber")
-        self.uwnetid = data.get("AdvisingUWNetID")
-        self.regid = data.get("AdvisingRegID")
-        self.program = data.get("AdvisingProgram")
-        self.booking_url = data.get("BookingUrl")
-        self.is_active = data.get("StudentAdvisingIsActive", False)
-        self.is_dept_adviser = data.get("IsDepartmentAdviser", False)
-        self.metadata = data.get("Metadata")
-        self.pronouns = data.get("AdvisingPronouns")
-
-    def is_honors_program(self):
-        return self.program == "UW Honors"
-
-    def json_data(self):
-        return {
-            'email_address': self.email_address,
-            'full_name': self.full_name,
-            'pronouns': self.pronouns,
-            'phone_number': self.phone_number,
-            'program': self.program,
-            'uwnetid': self.uwnetid,
-            'regid': self.regid,
-            'booking_url': self.booking_url,
-            'is_active': self.is_active,
-            'is_dept_adviser': self.is_dept_adviser,
-            'is_honors_program': self.is_honors_program(),
-            'metadata': self.metadata
-            }
-
-    def __str__(self):
-        return json.dumps(self.json_data())
-
-
 class Term(models.Model):
     SPRING = 'spring'
     SUMMER = 'summer'
@@ -321,7 +271,7 @@ class Term(models.Model):
 
     def is_grading_period_open(self, cmp_dt=None):
         if cmp_dt is None:
-            cmp_dt = sws_now()
+            cmp_dt = datetime.now()
 
         if self.is_summer_quarter():
             open_date = self.aterm_grading_period_open
@@ -334,13 +284,13 @@ class Term(models.Model):
 
     def is_grading_period_past(self, cmp_dt=None):
         if cmp_dt is None:
-            cmp_dt = sws_now()
+            cmp_dt = datetime.now()
         return (self.grade_submission_deadline is None or
                 cmp_dt > self.grade_submission_deadline)
 
     def get_week_of_term(self, cmp_dt=None):
         if cmp_dt is None:
-            cmp_dt = sws_now()
+            cmp_dt = datetime.now()
         return self.get_week_of_term_for_date(cmp_dt)
 
     def get_week_of_term_for_date(self, date):
@@ -683,7 +633,7 @@ class Section(models.Model):
 
     def is_grading_period_open(self, cmp_dt=None):
         if cmp_dt is None:
-            cmp_dt = sws_now()
+            cmp_dt = datetime.now()
 
         if self.is_summer_a_term():
             open_date = self.term.aterm_grading_period_open
@@ -1176,7 +1126,7 @@ class NoticeAttribute(models.Model):
 
     def get_value(self):
         if self.data_type == "date":
-            return date_to_str(self._date_value)
+            return self._date_value.strftime("%Y-%m-%d")
         if self.data_type == "string":
             return self._string_value
         if self.data_type == "url":
