@@ -1,6 +1,3 @@
-# Copyright 2021 UW-IT, University of Washington
-# SPDX-License-Identifier: Apache-2.0
-
 """
 Interfacing with the Student Web Service, Person resource
 """
@@ -11,14 +8,16 @@ from uw_sws import get_resource
 
 
 logger = logging.getLogger(__name__)
-person_url = "/student/v5/person/{}.json"
+sws_url_prefix = "/student/v5/person/"
+sws_url_suffix = ".json"
 
 
 def get_person_by_regid(regid):
     """
     Returns a uw_sws.models.SwsPerson object
     """
-    return _process_json_data(get_resource(person_url.format(regid)))
+    url = sws_url_prefix + regid + sws_url_suffix
+    return _process_json_data(get_resource(url))
 
 
 def _process_json_data(person_data):
@@ -26,28 +25,24 @@ def _process_json_data(person_data):
     Returns a uw_sws.models.SwsPerson object
     """
     person = SwsPerson()
-    if person_data.get("BirthDate"):
-        person.birth_date = parse(person_data.get("BirthDate")).date()
-    person.directory_release = person_data.get("DirectoryRelease")
-    person.email = person_data.get("Email")
-    person.employee_id = person_data.get("EmployeeID")
-    person.first_name = person_data.get("FirstName")
-    person.gender = person_data.get("Gender")
-    person.last_name = person_data.get("LastName")
-    person.pronouns = person_data.get("Pronouns")
-    person.student_name = person_data.get("StudentName")
+    if person_data["BirthDate"]:
+        person.birth_date = parse(person_data["BirthDate"]).date()
+    person.directory_release = person_data["DirectoryRelease"]
+    person.email = person_data["Email"]
+    person.employee_id = person_data["EmployeeID"]
+    person.first_name = person_data["FirstName"]
+    person.gender = person_data["Gender"]
+    person.last_name = person_data["LastName"]
+    person.student_name = person_data["StudentName"]
 
-    if person_data.get("Veteran") is not None:
-        person.veteran_code = person_data["Veteran"].get("Code")
-
-    if person_data.get("LastEnrolled") is not None:
+    if person_data["LastEnrolled"] is not None:
         last_enrolled = LastEnrolled()
         last_enrolled.href = person_data["LastEnrolled"]["Href"]
         last_enrolled.quarter = person_data["LastEnrolled"]["Quarter"]
         last_enrolled.year = person_data["LastEnrolled"]["Year"]
         person.last_enrolled = last_enrolled
 
-    if person_data.get("LocalAddress") is not None:
+    if person_data["LocalAddress"] is not None:
         address_data = person_data["LocalAddress"]
         local_address = StudentAddress()
         local_address.city = address_data["City"]
@@ -59,9 +54,9 @@ def _process_json_data(person_data):
         local_address.zip_code = address_data["Zip"]
         person.local_address = local_address
 
-    person.local_phone = person_data.get("LocalPhone")
+    person.local_phone = person_data["LocalPhone"]
 
-    if person_data.get("PermanentAddress") is not None:
+    if person_data["PermanentAddress"] is not None:
         perm_address_data = person_data["PermanentAddress"]
         permanent_address = StudentAddress()
         permanent_address.city = perm_address_data["City"]
@@ -73,11 +68,11 @@ def _process_json_data(person_data):
         permanent_address.zip_code = perm_address_data["Zip"]
         person.permanent_address = permanent_address
 
-    person.permanent_phone = person_data.get("PermanentPhone")
-    person.uwregid = person_data.get("RegID")
-    person.student_number = person_data.get("StudentNumber")
-    person.student_system_key = person_data.get("StudentSystemKey")
-    person.uwnetid = person_data.get("UWNetID")
-    person.visa_type = person_data.get("VisaType")
+    person.permanent_phone = person_data["PermanentPhone"]
+    person.uwregid = person_data["RegID"]
+    person.student_number = person_data["StudentNumber"]
+    person.student_system_key = person_data["StudentSystemKey"]
+    person.uwnetid = person_data["UWNetID"]
+    person.visa_type = person_data["VisaType"]
 
     return person
