@@ -1,6 +1,3 @@
-# Copyright 2021 UW-IT, University of Washington
-# SPDX-License-Identifier: Apache-2.0
-
 """
 Interfacing with the Student Web Service, for Section and Course resources.
 """
@@ -12,10 +9,9 @@ from restclients_core.thread import generic_prefetch
 from uw_sws.exceptions import InvalidSectionID, InvalidSectionURL
 from restclients_core.exceptions import DataFailureException
 from uw_sws import get_resource, encode_section_label, UWPWS
-from uw_sws.util import str_to_date
 from uw_sws.term import get_term_by_year_and_quarter
 from uw_sws.models import (
-    Section, SectionReference, FinalExam,
+    Section, SectionReference, FinalExam, str_to_date,
     SectionMeeting, GradeSubmissionDelegate, Person)
 
 
@@ -356,7 +352,7 @@ def _json_to_section(section_data,
     if is_valid_sln(section_data.get("SLN")):
         section.sln = int(section_data["SLN"])
 
-    _set_summer_term(section_data, section)
+    section.summer_term = section_data.get("SummerTerm", "")
     section.delete_flag = section_data.get("DeleteFlag", "")
     section.current_enrollment = int(section_data['CurrentEnrollment'])
 
@@ -521,18 +517,14 @@ def _json_to_section(section_data,
         comments = section_data["TimeScheduleComments"]["SectionComments"]
         if comments.get("Lines"):
             for line in comments["Lines"]:
-                if is_remote(line):
+                if (line.get("Text") and
+                        "OFFERED VIA REMOTE LEARNING" in line["Text"]):
                     section.is_remote = True
                     break
 
     return section
 
 
-def is_remote(comment_dict):
-    return (comment_dict.get("Text") and
-            "OFFERED VIA REMOTE" in comment_dict["Text"])
-
-
 def is_a_term(str):
     return str is not None and len(str) > 0 and\
         str.lower() == Section.SUMMER_A_TERM
@@ -553,11 +545,3 @@ def is_valid_section_label(label):
         return section_label_pattern.match(label) is not None
     except TypeError:
         return False
-
-
-def _set_summer_term(section_data, section):
-    section.summer_term = section_data.get("SummerTerm", "")
-    if (section.term.is_summer_quarter() and len(section.summer_term) == 0 and
-            section.is_campus_pce() and not section.for_credit()):
-        section.summer_term = "Full-term"
-        # PCE non-credit summer term courses are full-term by default
