@@ -1,6 +1,3 @@
-# Copyright 2021 UW-IT, University of Washington
-# SPDX-License-Identifier: Apache-2.0
-
 from datetime import datetime, timedelta
 from unittest import TestCase
 from uw_sws.util import fdao_sws_override
@@ -11,13 +8,15 @@ from uw_sws.exceptions import (InvalidSectionID, InvalidSectionURL,
                                InvalidCanvasIndependentStudyCourse,
                                InvalidCanvasSection)
 from uw_sws import use_v5_resources
-from uw_sws.section import (
-    get_section_by_label, get_joint_sections, get_linked_sections,
-    get_sections_by_instructor_and_term, get_sections_by_curriculum_and_term,
-    get_sections_by_building_and_term, get_changed_sections_by_term,
-    get_last_section_by_instructor_and_terms, validate_section_label,
-    get_sections_by_delegate_and_term, is_a_term, is_b_term,
-    is_full_summer_term, is_valid_sln, is_remote)
+from uw_sws.section import get_section_by_label, \
+    get_joint_sections, get_linked_sections, \
+    get_sections_by_instructor_and_term, \
+    get_sections_by_curriculum_and_term, \
+    get_sections_by_building_and_term, \
+    get_last_section_by_instructor_and_terms, \
+    get_changed_sections_by_term, validate_section_label, \
+    get_sections_by_delegate_and_term, \
+    is_a_term, is_b_term, is_full_summer_term, is_valid_sln
 
 
 @fdao_pws_override
@@ -542,7 +541,7 @@ class SWSTestSectionData(TestCase):
             'Canvas section SIS ID')
 
         # Independent study section
-        section = get_section_by_label('2020,summer,PHIL,600/A')
+        section = get_section_by_label('2013,summer,PHIL,600/A')
 
         # ..missing instructor regid
         self.assertRaises(InvalidCanvasIndependentStudyCourse,
@@ -552,11 +551,11 @@ class SWSTestSectionData(TestCase):
             'A9D2DDFA6A7D11D5A4AE0004AC494FFE')
         self.assertEquals(
             section.canvas_course_sis_id(),
-            '2020-summer-PHIL-600-A-A9D2DDFA6A7D11D5A4AE0004AC494FFE',
+            '2013-summer-PHIL-600-A-A9D2DDFA6A7D11D5A4AE0004AC494FFE',
             'Canvas course SIS ID')
         self.assertEquals(
             section.canvas_section_sis_id(),
-            '2020-summer-PHIL-600-A-A9D2DDFA6A7D11D5A4AE0004AC494FFE--',
+            '2013-summer-PHIL-600-A-A9D2DDFA6A7D11D5A4AE0004AC494FFE--',
             'Canvas section SIS ID')
 
     def test_summer_terms(self):
@@ -571,11 +570,13 @@ class SWSTestSectionData(TestCase):
         self.assertFalse(section.is_same_summer_term("B-term"))
         self.assertFalse(section.is_same_summer_term(None))
 
-        section = get_section_by_label('2020,summer,EDIT,120/B')
-        self.assertFalse(section.for_credit())
+        section = get_section_by_label('2013,summer,PHIL,600/A')
+        # section.summer_term is ""
         self.assertFalse(section.is_summer_a_term())
         self.assertFalse(section.is_summer_b_term())
-        self.assertTrue(section.is_full_summer_term())
+        self.assertFalse(section.is_full_summer_term())
+        self.assertTrue(section.is_same_summer_term(None))
+        self.assertTrue(section.is_same_summer_term(""))
 
     def test_summer_term_statics(self):
         self.assertTrue(is_a_term("A-term"))
@@ -718,7 +719,3 @@ class SWSTestSectionData(TestCase):
         self.assertTrue(section.is_remote)
         self.assertTrue(section.json_data()['is_remote'])
         self.assertTrue(section.is_source_sdb())
-
-        self.assertTrue(is_remote({"Text": "OFFERED VIA REMOTE LEARNING"}))
-        self.assertTrue(is_remote({"Text": "LECTURES ARE OFFERED VIA REMOTE"}))
-        self.assertFalse(is_remote({"Text": "PERSON"}))
